@@ -24,11 +24,6 @@ class QalxAdapter(object):
     The base class for a QalxAdapter. An adapter is the interface for the
     entity to the rest api.  This allows us to have a consistent interface
     across all entity types.
-    Can be instatiated in two ways:
-
-    QalxAdapter(entity_type='item') -> Returns a :class:`QalxItem` instance
-
-    QalxItem() -> Returns a :class:`QalxItem` instance
     """
 
     # Certain keys shouldn't be attemped to be saved
@@ -111,9 +106,9 @@ class QalxAdapter(object):
 
         try:
             endpoint = getattr(self.session.rest_api, method.lower())
-            self.session.log.debug(str(endpoint))
+            self.session.log.debug(f"{self.__class__.__name__}#{method}")
         except AttributeError:
-            raise QalxError(f"{method} not recognised.")
+            raise QalxError(f"`{method}` not recognised.")
 
         success, data = endpoint(*args, data=kwargs, headers=headers)
 
@@ -158,7 +153,9 @@ class QalxAdapter(object):
             raise QalxError("`meta` kwarg must be a `dict`")
         return kwargs
 
-    def _process_api_response(self, response, entity_class=None, **kwargs):
+    def _process_api_response(
+        self, response, entity_class=None, *args, **kwargs
+    ):
         """
         Hook for processing the response from the API.  By default
         returns an instance of self.entity_class.  kwargs can be provided
@@ -169,7 +166,9 @@ class QalxAdapter(object):
         """
         if entity_class is None:
             entity_class = self.entity_class
-        return entity_class(response, **kwargs)
+        return entity_class(
+            response, _region=self.session.config.get("REGION"), **kwargs
+        )
 
     def _add_tags(self, entity):
         """
@@ -232,8 +231,8 @@ class QalxAdapter(object):
         endpoint = self.detail_endpoint(guid=guid, *args, **kwargs)
         resp = self._process_api_request("get", endpoint, *args, **kwargs)
         self.session.log.debug(
-            f"get {self.entity_class.entity_type} with "
-            f"guid {guid} with {endpoint}"
+            f"get `{self.entity_class.entity_type}` with "
+            f"guid `{guid}` with `/{endpoint}`"
         )
         return self._process_api_response(resp)
 
@@ -245,8 +244,8 @@ class QalxAdapter(object):
         :param query: The mongoDB query
         :type query: dict
         :return: an instance of `self.entity_class`
-        :raises: `QalxMultipleEntityReturned`
-        :raises: `QalxEntityNotFound`
+        :raises QalxMultipleEntityReturned:
+        :raises QalxEntityNotFound:
         """
         return self.find(many=False, limit=2, query=query, **kwargs)
 
@@ -276,7 +275,7 @@ class QalxAdapter(object):
         list_endpoint = self.list_endpoint(**kwargs)
 
         self.session.log.debug(
-            f"find {self.entity_class.entity_type} with {list_endpoint}"
+            f"find `{self.entity_class.entity_type}` with `/{list_endpoint}`"
         )
         if include_session_tags and self.session.tags:
             # There are tags on this session, modify the query given (if
@@ -336,9 +335,9 @@ class QalxAdapter(object):
         a subset of the data is required then provide the query within the
         aggregation pipeline
 
-        :param aggregate:The aggregation pipeline
+        :param aggregate: The aggregation pipeline
         :type aggregate: list
-        :return: Instance of ~pyqalx.core.entities.entity.AggregationResult
+        :return: :class:`~pyqalx.core.entities.entity.AggregationResult`
         """
         try:
             aggregate = bson_extra.dumps(aggregate)
@@ -360,7 +359,8 @@ class QalxAdapter(object):
         """
         Reloads the current entity from the API
 
-        :return: A refreshed instance of `self.entity`
+        :param entity: An instance of `self.entity_class`
+        :return: A refreshed instance of `self.entity_class`
         """
         return self.get(entity["guid"], *args, **kwargs)
 
@@ -390,8 +390,8 @@ class QalxAdapter(object):
         endpoint = self.detail_endpoint(guid=guid, *args, **kwargs)
         keys_to_save = self.get_keys_to_save(entity=entity)
         self.session.log.debug(
-            f"save {self.entity_class.entity_type} with "
-            f"guid {guid} with {endpoint}"
+            f"save `{self.entity_class.entity_type}` with "
+            f"guid `{guid}` with `/{endpoint}`"
         )
 
         resp = self._process_api_request("patch", endpoint, **keys_to_save)
@@ -401,14 +401,15 @@ class QalxAdapter(object):
         """
         Archives `entity`
 
+        :param entity: An instance of `self.entity_class`
         :return: The archived instance of `entity`
         """
         guid = entity["guid"]
         detail_endpoint = self.detail_endpoint(guid=guid, *args, **kwargs)
         endpoint = f"{detail_endpoint}/archive"
         self.session.log.debug(
-            f"archive {self.entity_class.entity_type} with "
-            f"guid {guid} with {endpoint}"
+            f"archive `{self.entity_class.entity_type}` with "
+            f"guid `{guid}` with `/{endpoint}`"
         )
 
         resp = self._process_api_request("patch", endpoint)
@@ -417,6 +418,7 @@ class QalxAdapter(object):
     def delete(self, entity, *args, **kwargs):
         """
         Deletes the given entity from the API
+
         :param entity: An instance of QalxEntity
         """
         detail_endpoint = self.detail_endpoint(
@@ -629,13 +631,17 @@ class QalxUnpackableAdapter(QalxAdapter):
 
     def get(self, guid, child_fields=None, unpack=True, *args, **kwargs):
         """
-        Unpackable entities need to be unpacked after retrieval
+        Gets the entity for the given `guid` and unpacks it if specified.
+        Provide `child_fields` to restrict the fields returned on unpacked
+        children
 
         :param guid: The `guid` of the entity to get
-        :param unpack: Should the adapter be unpacked. Defaults to True
+        :type guid: str
         :param child_fields: A list of fields that should be returned from
-        child entities
+                             child entities
         :type child_fields: list
+        :param unpack: Should the child entities be unpacked. Defaults to True
+        :type unpack: bool
         :return: An unpacked entity
         """
         entity = super(QalxUnpackableAdapter, self).get(
@@ -660,12 +666,13 @@ class QalxUnpackableAdapter(QalxAdapter):
     def find(self, many=True, child_fields=None, *args, **kwargs):
         """
         Return multiple packed entities from the API
-        :param many:Are many results expected or just one?
-        :type many:bool
+
+        :param many: Are many results expected or just one?
+        :type many: bool
         :param child_fields: A list of fields that should be returned from
-        child entities
+                             child entities
         :type child_fields: list
-        :return:A list of entities
+        :return: A list of entities
         """
         entities = super(QalxUnpackableAdapter, self).find(
             many=many, *args, **kwargs
@@ -681,6 +688,9 @@ class QalxUnpackableAdapter(QalxAdapter):
         When saving an unpacked entity the kids need to be packed. To save
         having to unpack them again just save the original kids and replace
         them with the packed values after saving
+
+        :param entity: An instance of `self.entity_class`
+        :return: An updated instance of `self.entity_class`
         """
         has_kids_key = self.kids in entity.keys()
         if has_kids_key:
@@ -696,15 +706,29 @@ class QalxUnpackableAdapter(QalxAdapter):
         return entity
 
     def cache_kids(self, kwargs):
+        """
+        Gets the kids from the given kwargs
+
+        :param kwargs:a dict with a `self.kids` key
+        :type kwargs: dict
+        :return:The value of the `self.kids` key or None
+        """
         return kwargs.get(self.kids, None)
 
     def save_kids_on_entity(self, entity, kids):
+        """
+        Updates the given `self.kids` key on the entity with the given kids
+
+        :param entity: An entity to be updated
+        :param kids: The kids to update the entity with
+        """
         entity[self.kids] = kids
 
     def add(self, **kwargs):
         # Need to validate before we pack the kids up
         kwargs = self._validate(**kwargs)
         # Cache the kids to reassign them to the newly created entity
+
         cached_kids = self.cache_kids(kwargs)
         kwargs = self._pack_kids_for_request(kwargs)
         entity = super(QalxUnpackableAdapter, self).add(
@@ -739,7 +763,7 @@ class QalxSignalAdapter(QalxAdapter):
         guid = entity["guid"]
         endpoint = self.detail_endpoint(guid=guid, **kwargs)
         self.session.log.debug(
-            f"terminate {self.entity_class.entity_type} with guid {guid} with {endpoint}"  # noqa
+            f"terminate `{self.entity_class.entity_type}` with guid `{guid}` with `/{endpoint}`"  # noqa
         )
         signal = self.signal_class._terminate_signal(*args, **kwargs)
 
@@ -750,7 +774,7 @@ class QalxSignalAdapter(QalxAdapter):
         endpoint = self.detail_endpoint(guid=guid, **kwargs)
         signal = self.signal_class._stop_signal(stop)
         self.session.log.debug(
-            f"signal {signal} {self.entity_class.entity_type} with guid {guid} with {endpoint}"  # noqa
+            f"signal `{signal}` on `{self.entity_class.entity_type}` with guid `{guid}` with `/{endpoint}`"  # noqa
         )
         self._process_api_request("patch", endpoint, signal=signal)
 
@@ -774,20 +798,20 @@ class QalxNamedEntityAdapter(QalxAdapter):
     """
 
     def get_by_name(self, name, **kwargs):
-        """a single entity by name
+        """gets a single entity by name
 
         :param name: name of entity
         :type name: str
         :param kwargs: Keyword arguments to be used in the find method
         :return: instance of `self.entity_class`
-        :raises: pyqalx.errors.QalxReturnedMultipleError,
-                 pyqalx.errors.QalxEntityNotFound
+        :raises QalxMultipleEntityReturned:
+        :raises QalxEntityNotFound:
         """
         return self.find_one(query={"name": name}, **kwargs)
 
     def get_or_create(self, name, meta=None, **kwargs):
         """
-        Gets an Entity by the given name or creates it if it doesn't exist
+        Gets an entity by the given name or creates it if it doesn't exist
 
         :param name: The `name` that to use to get or create the entity by
         :type name: str
@@ -863,8 +887,8 @@ class QalxValidateBlueprintAdapter(QalxAdapter):
         the blueprint based on the `blueprint_name` and then ensure that
         the schema validates correctly against the data that you are updating
         the entity with
+
         :param entity: The entity instance that you are saving
-        :type entity: entities.QalxEntity instance
         :param blueprint_name: the name of the blueprint
         :type blueprint_name: str, None
         :return: A valid `self.entity_class` instance
@@ -936,11 +960,14 @@ class QalxFileAdapter(QalxAdapter):
         automatically for you after the entity itself has been created.  Pass
         `upload=False` through to stop this from happening and upload the file
         yourself
+
         :param source: The input file path or stream
         :param file_name: The optional file name
         :param upload: Whether the file should be automatically uploaded or not
+        :type upload: bool
         :param encrypt: Whether the file should be automatically encrypted if
          the KEYFILE is present
+        :type encrypt: bool
         :return: A valid entity
         """
         entity = super(QalxFileAdapter, self).add(
@@ -962,12 +989,16 @@ class QalxFileAdapter(QalxAdapter):
     ):  # noqa
         """
         Saves an entity - optionally updating any file data.
+
         :param entity: The entity that is being saved
         :param source: The input file path or stream
         :param file_name: The optional file name
+        :type file_name: str
         :param upload: Whether the file should be automatically uploaded or not
+        :type upload: bool
         :param encrypt: Whether the file should be automatically encrypted if
          the KEYFILE is present
+        :type encrypt: bool
         :return: A valid entity
         """
         entity = super(QalxFileAdapter, self).save(
@@ -1012,14 +1043,13 @@ class QalxUpdateStatusAdapter(QalxAdapter):
         Updates the status of an entity
 
         :param entity: The entity that is being updated
-        :type entity: An instance of ~entities.entity.QalxEntity
         :param status: The status to update to
-        :type: status: str
+        :type status: str
         """
         guid = entity["guid"]
         endpoint = self.detail_endpoint(guid=guid, **kwargs)
         self.session.log.debug(
-            f"update status{self.entity_class.entity_type} with guid {guid} with {endpoint}"  # noqa
+            f"update status `{self.entity_class.entity_type}` with guid `{guid}` with `/{endpoint}`"  # noqa
         )
         status_dict = {"message": status}
         self._process_api_request("patch", endpoint, status=status_dict)
