@@ -13,10 +13,8 @@ from ..errors import QalxFactoryValidationError, QalxAPIResponseError
 
 class QalxFactory(QalxFileAdapter):
     """
-    Provides interaction with the qalx API.
-
-    Class attributes
-        _entity_class: The entity class is a qalx factory
+    Provides an interface for accessing the API for
+    :class:`~pyqalx.core.entities.factory.Factory` entities
     """
 
     _entity_class = Factory
@@ -31,6 +29,7 @@ class QalxFactory(QalxFileAdapter):
 
         :param plan_path:   A local path to the .yaml file that contains the
                             factory plan definition
+        :type plan_path: str
 
         :raises QalxFactoryValidationError:     If the .yaml file does not
                                                 exist, if there are any errors
@@ -49,7 +48,9 @@ class QalxFactory(QalxFileAdapter):
                 f"There was an error validating the factory plan:\n\n{exc}"
             )
 
-    def add(self, name, source=None, file_name="", meta=None, **kwargs):
+    def add(
+        self, name, source=None, file_name="", meta=None, upload=True, **kwargs
+    ):
         """
         Adds a `Factory` instance
 
@@ -65,6 +66,8 @@ class QalxFactory(QalxFileAdapter):
         :type  file_name:   str
         :param meta:        A dictionary of metadata to store
         :type  meta:        dict
+        :param upload: Whether the file should be automatically uploaded or not
+        :type upload: bool
 
         :return: A newly created `Factory` instance
         """
@@ -75,11 +78,14 @@ class QalxFactory(QalxFileAdapter):
             file_name=file_name,
             meta=meta,
             file_key=self.entity_class._file_key,
+            upload=upload,
             encrypt=False,
             **kwargs,
         )
 
-    def save(self, entity, source=None, file_name="", **kwargs):
+    def save(
+        self, entity, source=None, file_name="", upload=True, *args, **kwargs
+    ):
         """
         Saves an updated existing `Factory` instance.
 
@@ -93,9 +99,53 @@ class QalxFactory(QalxFileAdapter):
                             file path is given for source parameter.
                             Required if an `io` object
         :type  file_name:   str
-
+        :param upload: Whether the file should be automatically uploaded or not
+        :type upload: bool
         :return: An updated `Factory` instance
         """
         return super(QalxFactory, self).save(
-            entity=entity, source=source, file_name=file_name, **kwargs
+            entity=entity,
+            source=source,
+            file_name=file_name,
+            upload=upload,
+            encrypt=False,
+            *args,
+            **kwargs,
         )
+
+    def get(self, guid, *args, **kwargs):
+        # extended to create better autodocs
+        return super(QalxFactory, self).get(guid, *args, **kwargs)
+
+    def find(
+        self,
+        query=None,
+        sort=None,
+        skip=0,
+        limit=25,
+        many=True,
+        include_session_tags=True,
+        **kwargs,
+    ):
+        # extended to create better autodocs
+        return super(QalxFactory, self).find(
+            query=query,
+            sort=sort,
+            skip=skip,
+            limit=limit,
+            many=many,
+            include_session_tags=include_session_tags,
+            **kwargs,
+        )
+
+    def find_one(self, query, **kwargs):
+        # extended to create better autodocs
+        return super(QalxFactory, self).find_one(query=query, **kwargs)
+
+    def reload(self, entity, *args, **kwargs):
+        # extended to create better autodocs
+        return super(QalxFactory, self).reload(entity=entity, **kwargs)
+
+    def aggregate(self, aggregate, **kwargs):
+        # extended to create better autodocs
+        return super(QalxFactory, self).aggregate(aggregate=aggregate, **kwargs)
