@@ -3,6 +3,11 @@ from pyqalx.core.entities import Notification
 
 
 class QalxNotification(QalxAdapter):
+    """
+    Provides an interface for accessing the API for
+    :class:`~pyqalx.core.entities.notification.Notification` entities
+    """
+
     _entity_class = Notification
 
     def add(self, subject, message, to, cc=None, bcc=None, **kwargs):
