@@ -5,6 +5,11 @@ from pyqalx.core.errors import QalxInvalidBlueprintError
 
 
 class Blueprint(QalxEntity):
+    """
+    Provides an interface for creating blueprints.  Blueprints allow a user to
+    create items or sets in a consistent fashion
+    """
+
     entity_type = "blueprint"
 
     def _update_property(self, property_key, key, schema_value, required=False):
@@ -33,7 +38,7 @@ class Blueprint(QalxEntity):
     def item(cls):
         """
         A blueprint that gives the default blueprint structure for an
-        `entities.item.Item` entity
+        :class:`~pyqalx.core.entities.item.Item` entity
         """
         blueprint = cls._base_blueprint()
         blueprint["entity_type"] = Item.entity_type
@@ -47,7 +52,7 @@ class Blueprint(QalxEntity):
     def set(cls):
         """
         A blueprint that gives the default blueprint structure for an
-        `entities.set.Set` entity
+        :class:`~pyqalx.core.entities.set.Set` entity
         """
         blueprint = cls._base_blueprint()
         blueprint["entity_type"] = Set.entity_type
@@ -60,8 +65,9 @@ class Blueprint(QalxEntity):
     def check_schema(self, schema=None):
         """
         Checks that the given schema is structure correctly
+
         :param schema: The schema to validate.  Uses `self` if None
-        :type schema: None or Blueprint instance
+        :type schema: None or ~pyqalx.core.entities.blueprint.Blueprint
 
         :raises: jsonschema.SchemaError
         """
@@ -73,8 +79,7 @@ class Blueprint(QalxEntity):
         """
         Validate an entity against the blueprint schema locally.
 
-        :param entity: A full schema for an entity that can have a
-                             Blueprint
+        :param entity: A full schema for an entity that can have a Blueprint
         """
         validate(instance=entity, schema=self["schema"])
 
@@ -98,9 +103,13 @@ class Blueprint(QalxEntity):
     def add_data(self, key, schema_value, required=False):
         """
         Adds data to this item blueprint instance.
+
         :param key: The key in the data you want to add
+        :type key: str
         :param schema_value: The schema value you want to add
+        :type schema_value: str
         :param required: Is this key required?
+        :type required: bool
         :return: An updated instance of the item blueprint
         """
         return self._update_property(
@@ -113,9 +122,13 @@ class Blueprint(QalxEntity):
     def add_meta(self, key, schema_value, required=False):
         """
         Adds meta to this item blueprint instance.
+
         :param key: The key in the meta you want to add
+        :type key: str
         :param schema_value: The schema value you want to add
+        :type schema_value: str
         :param required: Is this key required?
+        :type required: bool
         :return: An updated instance of the item blueprint
         """
         return self._update_property(
@@ -131,13 +144,16 @@ class Blueprint(QalxEntity):
         provided then the set schema will always require that specific
         item blueprint for `key`.  If `item_blueprint` is not provided then
         the set blueprint will accept any data for `key` when being used
-        :param key: They `key` of the item you want the blueprint to validate
+
+        :param key: The `key` of the item you want the blueprint to validate
         :type key: str
         :param item_blueprint: If provided will save the `name` from the
-        blueprint against the `key`.  This means that whenever the set is
-        created you must use the same blueprint.
+                               blueprint against the `key`.
+                               This means that whenever the set is
+                               created you must use the same blueprint.
         :type item_blueprint: str
         :param required: Is this key required?
+        :type required: bool
         :return: An updated instance of the set blueprint
         """
         if item_blueprint is None:
