@@ -18,6 +18,31 @@ class QalxAddict(Dict):
     that we don't mutate the type to a QalxAddict instance
     """
 
+    def __getattr__(self, item):
+        """
+        By default `addict.Dict` will lookup the key when doing attribute access.
+        If the key doesn't exist then a KeyError will be raised due to the
+        `__missing__` method.  However, this breaks calls to `hasattr()` as that
+        catches the normal `AttributeError` that will be raised.  Therefore,
+        handle a key not existing by catching the KeyError and reraising as the
+        more expected type
+        """
+        try:
+            return super(QalxAddict, self).__getattr__(item)
+        except KeyError:
+            raise AttributeError(
+                "%r object has no attribute %r"
+                % (self.__class__.__name__, item)
+            )
+
+    def __missing__(self, key):
+        """
+        https://github.com/mewwts/addict#default-values
+        Ensures that if a key/attribute is accessed that is missing that a
+        KeyError is raised
+        """
+        raise KeyError(key)
+
     @classmethod
     def _hook(cls, item):
         """
@@ -38,7 +63,12 @@ class BaseQalxEntity(dict):
     all keys recursively.
     """
 
-    def __init__(self, *args):
+    def __init__(self, *args, **kwargs):
+        # If the `_region` was specified then this entity was loaded by an
+        # instance of QalxAdapter.  Set the `_region` as an instance attribute
+        # to be used when interfacing with remote services
+        self._region = kwargs.pop("_region", None)
+
         super(BaseQalxEntity, self).__init__(*args)
 
         for key, value in self.items():
@@ -77,7 +107,7 @@ class BaseQalxEntity(dict):
         `_broker_client` but NOT the dict key.  Only applies for top level
         dict keys
         """
-        return []
+        return ["_region"]
 
     def __setitem__(self, key, value):
         """
@@ -113,12 +143,21 @@ class BaseQalxEntity(dict):
             if self.get(key, sentinel) != value:
                 self[key] = value
 
+    def to_dict(self):
+        base = {}
+        for key, value in self.items():
+            base[key] = value.to_dict()
+        return base
+
 
 class QalxListEntity(BaseQalxEntity):
     """
     Simple wrapper around a pyqalxapi_dict so we can keep extra keys
     on the API list response.  Instantiates each entity in `data` to the
     correct QalxEntity subclass.
+
+    :param pyqalxapi_list_response_dict: A dict response from a REST API list endpoint
+    :type pyqalxapi_list_response_dict: dict
     """
 
     _data_key = "data"
@@ -126,7 +165,9 @@ class QalxListEntity(BaseQalxEntity):
     def __init__(self, pyqalxapi_list_response_dict, **kwargs):
         self.child = kwargs.pop("child")
         self._key_file = kwargs.pop("keyfile", None)
-        super(QalxListEntity, self).__init__(pyqalxapi_list_response_dict)
+        super(QalxListEntity, self).__init__(
+            pyqalxapi_list_response_dict, **kwargs
+        )
 
         if (
             self._data_key not in pyqalxapi_list_response_dict
@@ -154,6 +195,8 @@ class QalxListEntity(BaseQalxEntity):
             kwargs = {}
             if self._key_file is not None:
                 kwargs = {"keyfile": self._key_file}
+            # Ensure the region is set for all children
+            kwargs["_region"] = self._region
             value = [self.child(x, **kwargs) for x in value]
         super(QalxListEntity, self).__setitem__(key, value)
 
@@ -161,15 +204,18 @@ class QalxListEntity(BaseQalxEntity):
 class AggregationResult(QalxListEntity):
     """
     Class for aggregation result responses from the API
+
+    :param pyqalxapi_list_response_dict: A dict response from a REST API list endpoint
+    :type pyqalxapi_list_response_dict: dict
     """
 
 
 class QalxEntity(BaseQalxEntity):
-    """Base class for qalx entities_response.
+    """Base class for a response from the qalx API
 
     QalxEntity children need to be populated with either a
     `requests.models.Response` which is the type returned by the methods
-    on `pyqalxapi.api.PyQalxAPI` or with a `dict`.
+    on :class:`~pyqalx.transport.api.PyQalxAPI` or with a `dict`.
 
     Entities can behave either like a dict or attribute lookups can be used
     as getters/setters
@@ -243,9 +289,10 @@ class QalxFileEntity(QalxEntity):
                             decrypting the file data. If it is not provided
                             and the data was encrypted, the data will be read
                             in the encrypted format
+        :type key_file: str
         :return:    The content of the URL as a bytes object.  Accessible from
                     the `_file_bytes` attribute
-        :raises: pyqalx.errors.QalxError
+        :raises QalxError:
         """
         if not self.get(self._file_key):
             raise QalxError("Item doesn't have file data.")
@@ -283,12 +330,13 @@ class QalxFileEntity(QalxEntity):
                             and the data was encrypted, the data will be read
                             in the encrypted format
         :type key_file:     str
-        :raises: pyqalx.errors.QalxError
+        :returns: Path to file on disk
+        :raises QalxError:
         """
-        if filename is None:
-            filename = self[self._file_key]["name"]
         if self._file_bytes is None:
             self.read_file()
+        if filename is None:
+            filename = self[self._file_key]["name"]
         _filepath = os.path.join(filepath, filename)
         with open(_filepath, "wb") as f:
             f.write(self._file_bytes)
@@ -305,18 +353,21 @@ class QalxQueueableEntity(QalxEntity):
         """
         Submits an entity, entity guid or list of entities/entity guids
         to the given queue
-        :param payload:subclassed instance of ~entities.entity.QalxEntity,
-        a guid, or a list containing a combination of both
-        :param queue: An instance of ~entities.queue.Queue
-        Usage:
-        :type queue:~entities.queue.Queue
-        :param children:Whether we are submitting the child entities to the
-        queue rather than the given entity
+
+        Example usage for an Item:
+
+        >>> Item.add_to_queue(item, queue)
+        >>> Item.add_to_queue(item.guid, queue)
+        >>> Item.add_to_queue([item, item.guid], queue)
+
+        :param payload: subclassed instance of
+                        :class:`~pyqalx.core.entities.entity.QalxEntity`,
+                        a guid, or a list containing a combination of both
+        :param queue: An instance of :class:`~pyqalx.core.entities.queue.Queue`
+        :type queue: ~pyqalx.core.entities.queue.Queue
+        :param children: Whether we are submitting the child entities to the
+                         queue rather than the given entity
         :type children: bool
-        Example usage for an Item
-        Item.add_to_queue(item, queue)
-        Item.add_to_queue(item.guid, queue)
-        Item.add_to_queue([item, item.guid], queue)
         """
         entity_type = cls.entity_type
         if children:
