@@ -167,6 +167,7 @@ class QalxCLITabulation:
             # Many entities found matching the query.
             # Create a table to allow the user to pick which they want
             table = self.tabulate()
+
             if (
                 self.prompt_text
                 or self.entities_for_prompt["query"]["next"] is not None
@@ -190,22 +191,19 @@ class QalxCLITabulation:
                     if not prompt_message:
                         return
                     inp = click.prompt(prompt_message, default="")
-                    if has_next_page:
+
+                    if has_next_page and inp == "":
                         # If the user presses ENTER then we show the next page
                         # and append the results to the existing variables
-                        if inp == "":
-                            self._update_entities_for_prompt(
-                                getattr(
-                                    self.qalx_session, self.entity_type
-                                )._process_api_request(
-                                    "get",
-                                    self.entities_for_prompt["query"]["next"],
-                                )
+                        self._update_entities_for_prompt(
+                            getattr(
+                                self.qalx_session, self.entity_type
+                            )._process_api_request(
+                                "get", self.entities_for_prompt["query"]["next"]
                             )
-                            entities_for_prompt += self.entities_for_prompt[
-                                "data"
-                            ]
-                            table += self.tabulate()
+                        )
+                        entities_for_prompt += self.entities_for_prompt["data"]
+                        table += self.tabulate()
                     else:
                         # Case where they have provided an index. This needs to
                         # be in the range of the table that was built
